@@ -306,6 +306,8 @@ def {prop.name}(self) -> {prop.type_str}:
 
     # node
     node_properties_str = "\n".join(property_strs)
+    if hydrate:
+        node_properties_str = ""
     computed_property_getter_str = "\n".join(computed_property_getter_strs)
     node_conversion_map_str = f"_edgedb_conversion_map: T.ClassVar[T.Dict[str, str]] = {stringify_dict(node_edgedb_conversion_map)}"
     insert_link_conversion_map_str = f"_link_conversion_map: T.ClassVar[T.Dict[str, str]] = {stringify_dict(link_conversion_map)}"
